==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/msg_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if (isset($message_box) && $message_box == 'in_box') {
			    echo $lang['href_in_box'] . "<br />";
			}
			else {
				echo "<a href='msg_list.php' class=\"txt_sub_menu\">" . $lang['href_in_box'] . "</a><br />";
			}

			if (isset($message_box) && $message_box == 'out_box') {
			    echo $lang['href_out_box'] . "<br />";
			}
			else {
				echo "<a href='msg_list.php?out_box=1' class=\"txt_sub_menu\">" . $lang['href_out_box'] . "</a><br />";
			}

			if (isset($message_box) && $message_box == 'save_box') {
			    echo $lang['href_save_box'] . "<br />";
			}
			else {
				echo "<a href='msg_list.php?save_box=1' class=\"txt_sub_menu\">" . $lang['href_save_box'] . "</a><br />";
			}
			?>

			<a href="msg_compose.php" class="txt_sub_menu"><?php echo $lang['href_compose'];?></a><br />

		</td>
	</tr>
</table>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/msg_menu.inc.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table border="0" cellspacing="0" cellpadding="4" width="100%">
	<tr>
		<td class="txt_title">
			<?php echo $lang['section_menu'];?><br />
			<hr />
		</td>
	</tr>
	<tr>
		<td valign="top" class="txt_sub_menu_on">
			<?php
			if (isset($message_box) && $message_box == 'in_box' && $page_name_short == "msg_list") {
			    echo $lang['href_in_box'] . "<br />";
			}
			else {
				echo "<a href='msg_list.php' class=\"txt_sub_menu\">" . $lang['href_in_box'] . "</a><br />";
			}

			if (isset($message_box) && $message_box == 'out_box' && $page_name_short == "msg_list") {
			    echo $lang['href_out_box'] . "<br />";
			}
			else {
				echo "<a href='msg_list.php?out_box=1' class=\"txt_sub_menu\">" . $lang['href_out_box'] . "</a><br />";
			}

			if (isset($message_box) && $message_box == 'save_box' && $page_name_short == "msg_list") {
			    echo $lang['href_save_box'] . "<br />";
			}
			else {
				echo "<a href='msg_list.php?save_box=1' class=\"txt_sub_menu\">" . $lang['href_save_box'] . "</a><br />";
			}
			?>

			<a href="msg_compose.php" class="txt_sub_menu"><?php echo $lang['href_compose'];?></a><br />

		</td>
	</tr>
</table>
